OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migrimi në rrugë e sipër. Ju lutemi, pritni, teksa migrimi përfundon",
    "Migration started …" : "Migrimi filloi …",
    "Saved" : "U ruajt",
    "Not saved" : "Nuk u ruajt",
    "Sending…" : "dërgim",
    "Email sent" : "Email-i u dërgua",
    "Private" : "Private",
    "Local" : "Lokale",
    "Verify" : "Verifiko",
    "Verifying …" : "Duke verifikuar ...",
    "Unable to change password" : "S’arrin të ndryshojë fjalëkalimin",
    "Very weak password" : "Fjalëkalim shumë i dobët",
    "Weak password" : "Fjalëkalim i dobët",
    "So-so password" : "Fjalëkalim çka",
    "Good password" : "Fjalëkalim i mirë",
    "Strong password" : "Fjalëkalim i fortë",
    "Select a profile picture" : "Përzgjidhni një foto profili",
    "Groups" : "Grupe",
    "{actor} changed your password" : "{actor} ndryshoi fjalëkalimin tuaj ",
    "You changed your password" : "Ju ndëruat fjalëkalimin",
    "Your password was reset by an administrator" : "Fjalëkalimi juaj është rivendosur nga administratori",
    "{actor} changed your email address" : "{aktori} ndërroi emailin tuaj ",
    "You changed your email address" : "Ju ndryshuat  adresën e emailit tuaj",
    "Your email address was changed by an administrator" : "Adresa juaj e email-it është ndryshuar nga një administrator",
    "Security" : "Siguria",
    "You successfully logged in using two-factor authentication (%1$s)" : "Ju keni hyrë me sukses duke përdorur autentifikimin me dy faktorë ( %1$s )",
    "A login attempt using two-factor authentication failed (%1$s)" : "Një përpjekje e identifikimit me anë të autentifikimit me dy faktorë dështoi ( %1$s )",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>fjalëkalimi</strong> ose <strong>emaili</strong> juaj është modifikuar",
    "Couldn't remove app." : "S’hoqi dot aplikacionin.",
    "Couldn't update app." : "S’përditësoi dot aplikacionin.",
    "Wrong password" : "Fjalëkalim i gabuar",
    "No user supplied" : "S’u dha përdorues",
    "Authentication error" : "Gabim mirëfilltësimi",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Ju lutemi siguro një fjalëkalim të rikuperueshëm admini; përndryshe, të gjithë të dhënat e përdoruesit do të humbasin ",
    "Wrong admin recovery password. Please check the password and try again." : "Fjalëkalim i gabuar rikthimesh për përgjegjësin. Ju lutemi, kontrolloni fjalëkalimin dhe provoni përsëri.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Programi klient s’mbulon ndryshime fjalëkalimi, por kyçi i përdoruesi për fshehtëzime u përditësua me sukses.",
    "Federated Cloud Sharing" : "Ndarje Në Re të Federuar ",
    "Invalid SMTP password." : "Fjalëkalim SMTP i pavlefshëm",
    "Email setting test" : "Test i konfigurimeve të Email-it",
    "Well done, %s!" : "U krye, %s!",
    "If you received this email, the email configuration seems to be correct." : "Nëse keni marrë këtë email, konfigurimi i email-it duket të jetë i saktë.",
    "Email could not be sent. Check your mail server log" : "Email nuk mund të dërgohej. Kontrolloni logun e serverit tuaj të postës",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ndodhi një gabim gjatë dërgimit të email-it. Ju lutemi, rishikoni rregullimet tuaja. (Error: %s)",
    "Invalid mail address" : "Adresë email e pavlefshme",
    "Settings saved" : "Konfigurimet u ruajtën",
    "Unable to change full name" : "S’arrin të ndryshojë emrin e plotë",
    "Unable to change email address" : "Nuk mund të ndryshohet adresa e email-it",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Në mënyrë që të verifikoni llogarinë tuaj në Twitter, postojeni tweet-in e mëposhtme në Twitter (ju lutemi sigurohuni që ta postoni atë pa asnjë ndërprerje rrjeshti):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Në mënyrë që të verifikoni faqen tuaj të internetit, ruani përmbajtjen e mëposhtme në rrënjën tuaj të internetit në '.well-known / CloudIdVerificationCode.txt' (ju lutemi sigurohuni që teksti i plotë të jetë në një vijë):",
    "%1$s changed your password on %2$s." : "%1$s ju ka ndryshuar fjalëkalmin në %2$s.",
    "Your password on %s was changed." : "Fjalëkalimi juaj në %s u ndryshua. ",
    "Your password on %s was reset by an administrator." : "Fjalëkalimi juaj në %s u rivendos nga një administrator.",
    "Password for %1$s changed on %2$s" : "Fjalëkalimi për %1$s ndryshojë në %2$s",
    "Password changed for %s" : "Fjalëkalimi ndryshojë për %s",
    "If you did not request this, please contact an administrator." : "Nëse ju nuk e keni kërkuar këtë, ju lutem kontaktoni një administrator.",
    "Your email address on %s was changed." : "Adresa e juaj e email-it në %s u ndryshua",
    "Your email address on %s was changed by an administrator." : "Adresa e juaj e email-it në %s u ndryshua nga një adminstrator.",
    "Email address for %1$s changed on %2$s" : "Adresa e email-it për %1$s ndryshojë në %2$s",
    "Email address changed for %s" : "Adresa e email-it ndryshojë për %s",
    "The new email address is %s" : "Adresa e re e email-it është %s",
    "Your %s account was created" : "Llogaria juaj %s u krijua",
    "Welcome aboard" : "Mirë se vini në bord",
    "Welcome aboard %s" : "Mirë se vini në bord %s",
    "Your username is: %s" : "Emri juaj i përdoruesit është: %s",
    "Set your password" : "Vendos fjalëkalimin tënd",
    "Go to %s" : "Shko tek %s",
    "Install Client" : "Instalo Klient",
    "Apps" : "Aplikacione",
    "Settings" : "Rregullimet",
    "Personal" : "Personale",
    "Additional settings" : "Konfigurime shtesë",
    "Basic settings" : "Konfigurime bazike",
    "Sharing" : "Ndarje me të tjerët",
    "Personal info" : "Informacion personal",
    "Email server" : "Shërbyes email-esh",
    "Security & setup warnings" : "Sinjalizime sigurie & rregullimi",
    "Background jobs" : "Punët në background",
    "Create" : "Krijo",
    "Change" : "Ndrysho",
    "Delete" : "Fshij",
    "Unlimited" : "E pakufizuar",
    "Verifying" : "Duke verifikuar",
    "None" : "Asnjë",
    "Limit to groups" : "Kufizo grupet",
    "Save changes" : "Ruaj ndryshimet",
    "All" : "Krejt",
    "No results" : "Asnjë rezultat",
    "Update to {version}" : "Përditëso në {version}",
    "Remove" : "Hiqe",
    "Disable" : "Çaktivizoje",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një minimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një maksimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ky aplikacion s’mund të instalohet, ngaqë për të nuk plotësohen varësitë vijuese:",
    "View in store" : "Shiko në dyqan",
    "Visit website" : "Vizitoni sajtin",
    "Report a bug" : "Njoftoni një të metë",
    "User documentation" : "Dokumentim për përdoruesit",
    "Admin documentation" : "Dokumentim për përgjegjësit",
    "Developer documentation" : "Dokumentim për zhvillues",
    "Featured" : "I paraqitur",
    "No apps found for your version" : "S’u gjetën aplikacione për versionin tuaj",
    "Enable all" : "Aktivizoi të gjitha",
    "Allow filesystem access" : "Lejo aksesin e sistemit të skedarëve",
    "Rename" : "Rename",
    "Revoke" : "Anulo",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome për Android",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Sinkronizo klientin - {os}",
    "This session" : "Ky sesion",
    "Device" : "Pajisje",
    "Last activity" : "Aktiviteti i fundit",
    "Web, desktop and mobile clients currently logged in to your account." : "Klientë në rrjet, desktop dhe celular kanë hyrë aktualisht në  llogarinë tuaj.",
    "Error while creating device token" : "Gabim gjatë krijimit të token-ëve të pajisjejeve",
    "Error while deleting the token" : "Gabim gjatë fshirjes së token-it",
    "App name" : "Emër aplikacioni",
    "Create new app password" : "Krijoni fjalëkalim aplikacioni të ri",
    "Use the credentials below to configure your app or device." : "Përdorni kredencialet e mëposhtme për të konfiguruar aplikacionin apo pajisjen tuaj.",
    "For security reasons this password will only be shown once." : "Për arsye siguri ky fjalëkalim do të shofaqet vetëm një herv.",
    "Username" : "Emër përdoruesi",
    "Password" : "Fjalëkalim",
    "Done" : "U bë",
    "Copied!" : "U kopjua!",
    "Copy" : "Kopjo",
    "Remove group" : "Hiq grupin",
    "Your email address" : "Adresa juaj email",
    "No email address set" : "S’është caktuar adresë email",
    "Language" : "Gjuhë",
    "Help translate" : "Ndihmoni në përkthim",
    "Add" : "Shto",
    "Cancel" : "Anuloje",
    "{size} used" : "{madhësia} e përdorur",
    "New user" : "Përdorues i ri",
    "Display name" : "Shfaq emrin",
    "Email" : "Email",
    "Group admin for" : "Administratori i  grupit për",
    "Quota" : "Kuota",
    "User backend" : "Program klient i përdoruesit",
    "Storage location" : "Vendndodhje Depozite",
    "Last login" : "Hyrja e fundit",
    "Default quota" : "Kuota Parazgjedhje",
    "Name your device" : "Emërtoni pajisjen tuaj",
    "Adding your device …" : "Shtoni pajisjen tuaj ...",
    "Unnamed device" : "Paisje pa emër",
    "Your apps" : "Aplikacionet tuaja ",
    "Active apps" : "Aplikacionet aktive",
    "Disabled apps" : "Aplikacionet pa aftësi ",
    "Updates" : "Përditësime",
    "App bundles" : "Pako e aplikacionit ",
    "Details" : "Detaje",
    "Changelog" : "Katalogu i ndryshimeve",
    "Add group" : "Shto grup",
    "Admins" : "Administratorë",
    "Disabled users" : "Përdoruesit të çaktivizuar",
    "Show last login" : "Shfaq hyrjen e fundit",
    "Show user backend" : "Shfaq programin klient të përdoruesit",
    "Send email to new user" : "Dërgo email përdoruesi të ri",
    "Address" : "Adresa",
    "Full name" : "Emër i plotë",
    "Phone number" : "Numri i telefonit",
    "Twitter" : "Twitter",
    "Website" : "Faqe web-i",
    "Enable" : "Aktivizoje",
    "Never" : "Kurrë",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacioni është aktivizuar, por lyp të përditësohet. Do të ridrejtoheni te faqja e përditësimeve brenda 5 sekondash.",
    "App update" : "Përditësim aplikacioni",
    "Administrator documentation" : "Dokumentim për përgjegjës",
    "Documentation" : "Dokumentacioni",
    "Forum" : "Forum",
    "Login" : "Hyrje",
    "Plain" : "E thjeshtë",
    "NT LAN Manager" : "Përgjegjës Rrjeti NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Hapni dokumentimin",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Është e rëndësishme të ngrini këtë server për të qenë në gjendje të dërgoni email, si për rivendosjen e fjalëkalimeve dhe për njoftimet.",
    "Send mode" : "Mënyrë dërgimi",
    "Encryption" : "Fshehtëzim",
    "From address" : "Nga adresa",
    "Authentication method" : "Metodë mirëfilltësimi",
    "Authentication required" : "Lypset mirëfilltësim",
    "Server address" : "Adresë shërbyesi",
    "Port" : "Portë",
    "Credentials" : "Kredenciale",
    "SMTP Username" : "Emër përdoruesi SMTP",
    "SMTP Password" : "Fjalëkalim SMTP",
    "Save" : "Ruaj",
    "Send email" : "Dërgo email",
    "All checks passed." : "I kaloi krejt kontrollet.",
    "Version" : "Version",
    "Server-side encryption" : "Fshehtëzim më anë shërbyesi",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Enkriptimi nga ana e serverit bën të mundur enkriptimin e skedarëve të ngarkuar në këtë server. Kjo vjen me kufizime si një ndëshkim për performancën, prandaj e lejoni këtë vetëm nëse është e nevojshme.",
    "Enable server-side encryption" : "Aktivizo fshehtëzim më anë të shërbyesit",
    "Please read carefully before activating server-side encryption: " : "Ju lutemi, lexoni me kujdes përpara aktivizimit të fshehtëzimeve më anë shërbyesi: ",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Pasi të jetë aktivizuar fshehtëzimi, krejt kartelat e ngarkuara te shërbyesi nga kjo pikë e tutje do të fshehtëzohen pasi të jenë depozituar në shërbyes. Çaktivizimi i fshehtëzimit në një datë të mëvonshme do të jetë i mundur vetëm nëse moduli aktiv i fshehtëzimeve e mbulon këtë funksion, dhe nëse plotësohen krejt parakushtet (p.sh. caktimi i një kyçi rimarrjesh).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Vetëm shifrimi nuk garaton sigurinë e sistemit. Ju lutem shikoni dokumentimin për më shumë informacion mbi mënyrën si applikacioni punon, dhe përdorimin e rasteve të suportuara.",
    "Be aware that encryption always increases the file size." : "Kini parasysh që fshehtëzimi e rrit gjithnjë madhësinë e kartelës.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Është gjithmonë ide e mirë të krijohen kopjeruajtje të rregullta të të dhënave tuaja, në rast fshehtëzimi sigurohuni që bëni kopjeruajtje të kyçeve të fshehtëzimit, tok me të dhënat tuaja.",
    "This is the final warning: Do you really want to enable encryption?" : "Ky është sinjalizimi përfundimtar: Doni vërtet të aktivizohet fshehtëzimi?",
    "Enable encryption" : "Aktivizoni fshehtëzim",
    "No encryption module loaded, please enable an encryption module in the app menu." : "S’ka të ngarkuar modul fshehtëzimi, ju lutemi, aktivizoni një modul fshehtëzimi që nga menuja e aplikacionit.",
    "Select default encryption module:" : "Përzgjidhni modul parazgjedhje fshehtëzimi:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Lypset të migroni kyçet tuaj të fshehtëzimit nga fshehtëzimi i vjetër (ownCloud <= 8.0) te i riu. Ju lutemi, aktivizoni \"Modul parazgjedhje fshehtëzimesh\" dhe ekzekutoni 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Lypset të migroni kyçet tuaj të fshehtëzimit nga fshehtëzimi i vjetër (ownCloud <= 8.0) te i riu.",
    "Start migration" : "Fillo migrimin",
    "Last job execution ran %s. Something seems wrong." : "Ekzekutimi i punës së fundit vazhdoi %s. Diçka shkoi keq.",
    "Last job ran %s." : "Puna e fundit vazhdoi %s.",
    "Background job didn’t run yet!" : "Puna ne background nuk ka filluar akoma!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Për performancë optimale është e rëndësishme të konfigurosh punë të sfondit në mënyrë korrekte. Për raste më të mëdha 'Cron' është konfigurimi i rekomanduar. Ju lutem shih dokumentacionin për më shumë informacion.",
    "The cron.php needs to be executed by the system user \"%s\"." : "con.php duhet të ekzekutohet bga përdoruesi i sistemit \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Për të bërë këtë ekzekutim ju duhet shtesa PHP POSIX. Shikoni {linkstart} dokumentacionin e PHP {linkend} pë më shumë detaje.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Si admin ju mund të rregulloni mirë sjelljen e ndarjes. Ju lutem shih dokumentacionin për më shumë informacion.",
    "Allow apps to use the Share API" : "Lejoni aplikacionet të përdorin API Share",
    "Enforce expiration date" : "Detyro datë skadimi",
    "Allow public uploads" : "Lejo ngarkime publike",
    "Always ask for a password" : "Gjithmonë pyet për një fjalëkalim",
    "Enforce password protection" : "Detyro mbrojtje me fjalëkalim",
    "Allow resharing" : "Lejo rindarje",
    "Allow sharing with groups" : "Lejoni ndarje me grupe",
    "Restrict users to only share with users in their groups" : "Përdoruesve kufizoju të ndajnë gjëra vetëm me përdorues në grupin e tyre",
    "Exclude groups from sharing" : "Përjashtoni grupe nga ndarjet",
    "These groups will still be able to receive shares, but not to initiate them." : "Këto grupe prapë do të jenë në gjendje të marrin ndarje nga të tjerët, por jo të fillojnë të tilla.",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ky tekst do të shfaqet në linkun publik të faqes së ngarkuar kur lista e skedarit të jetë e fshehur.",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Zhvilluar nga {communityopen}komuniteti Nextcloud {linkclose},  {githubopen}kodi i hapur{linkclose} iështë licensuar sipar {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Pëlqeni faqen tonë në Facebook",
    "Follow us on Twitter" : "Na ndiqni në Twitter",
    "Check out our blog" : "Shikoni blogun tonë",
    "Subscribe to our newsletter" : "Abonohu në gazeten tonë",
    "Profile picture" : "Foto profili",
    "Upload new" : "Ngarko të re",
    "Select from Files" : "Përzgjidhni prej Kartelash",
    "Remove image" : "Hiqe figurën",
    "png or jpg, max. 20 MB" : "png ose jpg, maks. 20 MB",
    "Picture provided by original account" : "Foto e prurë nga llogaria origjinale",
    "Choose as profile picture" : "Zgjidhni një foto profili",
    "You are using <strong>%s</strong>" : "Ju po përdorni <strong>%s</strong>",
    "Your phone number" : "Numri juaj i telefonit",
    "Your postal address" : "Adresa juaj postale",
    "It can take up to 24 hours before the account is displayed as verified." : "Kjo mund të marrë mbi 24 orë, përpara se llogaria të shfaqet si e verifikuar.",
    "Link https://…" : "Linku https://…",
    "Twitter handle @…" : "Përdoruesi i Twitter @ ...",
    "Current password" : "Fjalëkalimi i tanishëm",
    "New password" : "Fjalëkalimi i ri",
    "Change password" : "Ndrysho fjalëkalimin",
    "Public" : "Publiku",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalim dhe përditësim aplikacionesh përmes shitores së aplikacioneve ose Federated Cloud Sharing",
    "You need to set your user email before being able to send test emails." : "Lypset të caktoni email-in tuaj si përdorues, përpara se të jeni në gjendje të dërgoni email-e provë.",
    "Close" : "Mbylleni",
    "All languages" : "Të gjitha gjuhët",
    "Everyone" : "Kushdo",
    "The app will be downloaded from the app store" : "Aplikacioni do të shkarkohet nga shitorja e aplikacioneve",
    "Error: This app can not be enabled because it makes the server unstable" : "Gabim: Ky aplikacion s’u aktivizua dot, ngaqë e bën shërbyesin të paqëndrueshëm.",
    "mail" : "email",
    "Test email settings" : "Testoni rregullimet e email-it",
    "Expire after " : "Skadon pas ",
    "days" : "ditësh",
    "Allow users to share via link" : "Lejoji përdoruesit të ndajnë me të tjerët përmes lidhjesh",
    "No display name set" : "S’është caktuar emër për në ekran",
    "For password reset and notifications" : "Për të rivendosur fjalëkalimin dhe njoftimet"
},
"nplurals=2; plural=(n != 1);");
